// Copyright 2023 Freedelity. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

import 'dart:async';

import 'package:flutter/services.dart';
import 'constants.dart';

export 'barcode_scanner.widget.dart';

enum BarcodeFormat {
  code39,
  code93,
  code128,
  ean8,
  ean13,
  itf,
  codabar,
  dataMatrix,
  qrCode;

  static BarcodeFormat? unserialize(int constant) {
    switch(constant) {
      case FORMAT_CODE_39:
        return BarcodeFormat.code39;
      case FORMAT_CODE_93:
        return BarcodeFormat.code93;
      case FORMAT_CODE_128:
        return BarcodeFormat.code128;
      case FORMAT_EAN_8:
        return BarcodeFormat.ean8;
      case FORMAT_EAN_13:
        return BarcodeFormat.ean13;
      case FORMAT_ITF:
        return BarcodeFormat.itf;
      case FORMAT_CODABAR:
        return BarcodeFormat.codabar;
      case FORMAT_DATAMATRIX:
        return BarcodeFormat.dataMatrix;
      case FORMAT_QR_CODE:
        return BarcodeFormat.qrCode;
      default:
        return null;
    }
  }
}

class Barcode {
  final BarcodeFormat format;
  final String value;

  Barcode({required this.format, required this.value});
}

abstract class BarcodeScanner {

  static const MethodChannel _channel = MethodChannel('be.freedelity/scanner/method');

  static Future toggleFlashlight() => _channel.invokeMethod('toggleTorch');
  static Future flipCamera() => _channel.invokeMethod('flipCamera');
  static Future stopScanner() => _channel.invokeMethod('stopScanner');
  static Future startScanner() => _channel.invokeMethod('startScanner');
}
